@@ -31,6 +31,10 @@ def unregister_appclass(app):
     _microapp_apps.remove(app)
 
 
+def is_appclass_registered(app):
+    return app in _microapp_apps
+
+
 def load_appclass(apppath, args=None, subargs=None, dapps=None):
     """select application class
 
@@ -98,8 +102,11 @@ def load_appclass(apppath, args=None, subargs=None, dapps=None):
                                      "Python module: " + apppath)
 
         elif os.path.isdir(apppath):
-            modname, mod = import_modulepath(apppath)
-            mods.append(mod)
+            try:
+                modname, mod = import_modulepath(apppath)
+                mods.append(mod)
+            except:
+                pass
 
     if app_class is None:
         for app in _microapp_apps: 
@@ -137,8 +144,8 @@ def load_appclass(apppath, args=None, subargs=None, dapps=None):
                    candidates[name] = obj
     if candidates:
         if fragment:
-            if hasattr(candidates, fragment):
-                app_class = getattr(candidates, fragment)
+            if fragment in candidates:
+                app_class = candidates[fragment]
 
             else:
                 raise UsageError("No app is found with a fragment of "
