@@ -199,6 +199,9 @@ class Group(MicroappObject, GroupArgParser, EntryEntity, ExitEntity):
 
         kwargs["add_help"] = False
 
+        if "description" not in kwargs and cls.__doc__ is not None:
+            kwargs["description"] = cls.__doc__
+
         obj = super(Group, cls).__new__(cls, *vargs, **kwargs)
         obj.manager = mgr
 
@@ -222,19 +225,19 @@ class Group(MicroappObject, GroupArgParser, EntryEntity, ExitEntity):
 #        # syntax --reduce 'sum(x, y)[ -> y]'
 #                #type=ArgType(None, True, None), action="append",
         obj.add_argument("--reduce", metavar="expr", delay=True,
-                action="append", help="reduce data from paths")
+                action="append", syshelp="reduce data from paths")
         obj.add_argument("--clone", metavar="expr", type=int,
-                help="dupulicate app")
+                syshelp="dupulicate app")
         obj.add_argument("--assigned-input", metavar="data",
-                help="assign input data to a specified edge")
+                syshelp="assign input data to a specified edge")
 
         obj.add_argument("--assert-in", metavar="expr", action="append",
-                type=bool, help="assertion test on input")
+                type=bool, syshelp="assertion test on input")
         obj.add_argument("--assert-out", metavar="expr", action="append",
-                type=bool, delay=True, help="assertion test on output")
+                type=bool, delay=True, syshelp="assertion test on output")
 
         obj.add_argument("--data-join", type=str, default="overwrite",
-                help="data combining method(block, overwrite:default, accumulate)")
+                syshelp="data combining method(block, overwrite:default, accumulate)")
 
         #obj.add_argument('--version', action='version', version=(cls._name_
         #        + " " + cls._version_))
