@@ -3,9 +3,7 @@
 
 from __future__ import print_function
 
-import sys
-import os
-import pkg_resources
+import sys, os, pkg_resources, tempfile, subprocess, shutil
 
 from typing import Any
 from microapp.error import UsageError
@@ -13,6 +11,24 @@ from microapp.utils import appdict
 from microapp.app import App
 
 
+
+_setup_template = """
+from setuptools import setup
+
+setup(
+    name= "{name}",
+    version="{version}",
+    description="{description}",
+    packages=[{packages}],
+    install_requires=[{install_requires}],
+    entry_points={{"microapp.{plugintype}": "{name} = {name}"}}
+)
+"""
+
+_init_template = """
+from .{module_name} import {class_name}
+"""
+
 # copied from distutils.core.py
 setup_keywords = ('distclass', 'script_name', 'script_args', 'options',
                   'name', 'version', 'author', 'author_email',
@@ -158,7 +174,7 @@ class ListApp(App):
         nsp = maxinfo[0] + maxinfo[1] + 3
 
         if appinfo:
-            print("\nMicroapp apps")
+            print("\n%s apps" % self.manager._name_)
             print("-----------------")
 
             for head, info in appinfo.items():
@@ -169,7 +185,7 @@ class ListApp(App):
                         print("%s%s%s : %s" % (name, " "*(nsp-nleft), ver, desc))
 
         if prjinfo:
-            print("\nMicroapp projects")
+            print("\n%s projects" % self.manager._name_)
             print("-----------------")
 
             for name, ver, desc in prjinfo:
@@ -181,7 +197,7 @@ class ListApp(App):
 
         nsp = maxinfo[0] + maxinfo[1] + 3
 
-        print("\nlocally installed Microapp apps")
+        print("\nlocally installed %s apps" % self.manager._name_)
 
         for head, info in appinfo.items():
             print("\n"+head)
@@ -194,7 +210,7 @@ class ListApp(App):
             else:
                 print("  N/A")
 
-        print("\nlocally installed Microapp projects")
+        print("\nlocally installed %s projects" % self.manager._name_)
         print("------------------------------------")
 
         if prjinfo:
@@ -264,6 +280,9 @@ class ListApp(App):
             self.print_merged_list(prjs, apps, maxinfo)
 
 
+        self.add_forward(data=apps)
+
+
 class ConfigApp(App):
     """read and write microapp configuration data"""
 
@@ -304,7 +323,7 @@ class RegisterApp(App):
         self.add_argument("app", nargs="*", help="Microapp apps")
 
     def perform(self, args):
-
+        pass
         # uploading app as well as project
 
         # requirements
@@ -317,18 +336,20 @@ class RegisterApp(App):
         # test
 
         # build
-        import distutils.core as distcore
+        #import distutils.core as distcore
 
-        if hasattr(distcore, "setup_keywords"):
-            setup_keywords = getattr(distcore, "setup_keywords")
+        #if hasattr(distcore, "setup_keywords"):
+        #    setup_keywords = getattr(distcore, "setup_keywords")
             
-        setup_kwargs = appdict()
+        #setup_kwargs = appdict()
          
         #import pdb; pdb.set_trace()
         # upload
 
 
 
+# TODO: check if app is local file or director
+# TODO: if not, check if remote app is microaopp or not
 class InstallApp(App):
     """install Microapp app from an indexing server"""
 
@@ -339,19 +360,116 @@ class InstallApp(App):
 
         self.add_argument("app", nargs="*", help="Microapp apps")
 
+        self.register_forward("data", help="installed apps")
+
     def perform(self, args):
 
-        # more inteligent searching
+        installed_apps = []
 
-        # install
+        for app in args.app:
 
-        pass
-        #import pdb; pdb.set_trace()
+            try:
+                from microapp.framework import load_appclass
+
+                spath = [p.strip() for p in app["_"].rsplit("#", 1)]
+
+                if len(spath) == 2:
+                    path, frag = spath
+
+                else:
+                    path, frag = spath[0], ""
+
+                appcls, _, _, _ = load_appclass(app["_"])
+ 
+                if os.path.isfile(path):
+
+                    with tempfile.TemporaryDirectory() as tempdir:
+                        pkgname = appcls._name_
+                        desc = appcls.__doc__ if appcls.__doc__ else "Microapp " + pkgname
+
+                        setupargs = {
+                            "name": appcls._name_,
+                            "version": appcls._version_,
+                            "description": desc,
+                            "packages": '"%s"' % pkgname,
+                            "install_requires": "",
+                            "plugintype": "apps"
+                        }
+
+                        with open(os.path.join(tempdir, "setup.py"), "w") as sf:
+                            sf.write(_setup_template.format(**setupargs))
+
+                        pkgdir = os.path.join(tempdir, pkgname)
+                        os.makedirs(pkgdir)
+
+                        filename = os.path.basename(path)
+                        modname, ext = os.path.splitext(filename)
+
+                        initargs = {
+                            "module_name": modname,
+                            "class_name": appcls.__name__
+                        }
+
+                        with open(os.path.join(pkgdir, "__init__.py"), "w") as pf:
+                            pf.write(_init_template.format(**initargs))
+
+                        shutil.copy(path, pkgdir)
+
+                        # install app
+                        pipcmd = [sys.executable, "-m", "pip", "-q",
+                                  "--disable-pip-version-check", "install",
+                                  "--disable-pip-version-check", tempdir]
+                        subprocess.run(pipcmd, cwd=tempdir)
+
+                        installed_apps.append(appcls._name_)
+
+                else:
+                        # install app
+                        pipcmd = [sys.executable, "-m", "pip", "-q", 
+                                  "--disable-pip-version-check", "install",
+                                  "--disable-pip-version-check", path]
+                        subprocess.run(pipcmd)
+
+            except UsageError as err:
+                raise
+                # TODO support remote install
+
+        self.add_forward(data=installed_apps)
+
+
+class UninstallApp(App):
+    """uninstall Microapp app"""
+
+    _name_ = "uninstall"
+    _version_ = "0.1.0"
+
+    def __init__(self, mgr):
+
+        self.add_argument("app", nargs="*", help="Microapp apps")
+
+        self.register_forward("data", help="uninstalled apps")
+
+    def perform(self, args):
+
+        uninstalled_apps = []
+
+        for app in args.app:
+
+            pipcmd = [sys.executable, "-m", "pip", "--disable-pip-version-check",
+                      "-q", "uninstall", "--yes", app["_"]]
+
+            subprocess.run(pipcmd)
+
+            uninstalled_apps.append(app)
+
+        self.add_forward(data=uninstalled_apps)
 
 
 mgmt_apps = appdict({
     HelpApp._name_ : HelpApp,
     ConfigApp._name_ : ConfigApp,
+    InstallApp._name_ : InstallApp,
+    UninstallApp._name_ : UninstallApp,
     RegisterApp._name_ : RegisterApp,
     ListApp._name_ : ListApp,
 })
