@@ -35,19 +35,19 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
 
         if sys.version_info < (3, 0):
             obj.add_argument("--multiproc-method",
-                    help="multiprocessing spawning method")
+                    syshelp="multiprocessing spawning method")
 
         obj.add_argument("--forward", metavar="expr", action="append",
-                delay=True, help="forward variables to next app")
+                delay=True, syshelp="forward variables to next app")
 
         obj.add_argument("--share", metavar="expr", action="append",
-                delay=True, help="share variables between sibling apps")
+                delay=True, syshelp="share variables between sibling apps")
 
         obj.add_argument("--shell", metavar="cmd", action="append",
-                delay=True, help="execute a shell command")
+                delay=True, syshelp="execute a shell command")
 
         obj.add_argument("--downcast", metavar="expr", action="append",
-                delay=True, help="downcast variables under this app")
+                delay=True, syshelp="downcast variables under this app")
 
         obj.add_argument('--version', action='version', version=(prog + " "
                 + cls._version_))
@@ -70,12 +70,13 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
     def _load_config(self):
 
         home = os.path.expanduser("~")
-        cfgdir = os.path.join(home, ".microapp")
-        self._cfgfile = os.path.join(cfgdir, "config")
+        cfgdir = os.path.join(home, ".microapp", self._name_)
 
-        if not os.path.exists(cfgdir):
+        if not os.path.isdir(cfgdir):
             os.makedirs(cfgdir)
 
+        self._cfgfile = os.path.join(cfgdir, "config")
+
         if os.path.isfile(self._cfgfile):
             with open(self._cfgfile) as f:
                 #config = json.load(f)
@@ -86,7 +87,8 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             now = datetime.datetime.now()
 
             created = appdict({"by": self._name_, "when": str(now)})
-            global_conf = appdict({"created": created})
+            global_conf = appdict({"created": created, "configdir": cfgdir,
+                            })
 
             config = appdict({"global" : global_conf, "project": appdict(),
                               "app": appdict()})
@@ -187,7 +189,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
     def perform(self, aargs):
         pass
 
-    def run_command(self, args=None, cwd=None, project_args=None, group_args=None,
+    def run_command(self, args=None, workdir=None, project_args=None, group_args=None,
                 app_args=None, forward=None, shared=None, downcast=None):
         """MicroappProject command execution entry"""
 
@@ -240,8 +242,9 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             ret = -1, None
 
             pwd = os.getcwd()
-            if cwd and os.path.isdir(cwd):
-                os.chdir(cwd)
+
+            if workdir and os.path.isdir(workdir):
+                os.chdir(workdir)
 
             pargs, aargs = args, []
 
@@ -376,7 +379,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
 
         return ret
 
-    def run_class(self, cls, cwd=None, project_args=None, group_args=None,
+    def run_class(self, cls, workdir=None, project_args=None, group_args=None,
                 app_args=None, forward=None, shared=None, downcast=None):
         """MicroappProject app execution entry"""
 
@@ -406,8 +409,9 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             ret = -1, None
 
             pwd = os.getcwd()
-            if cwd and os.path.isdir(cwd):
-                os.chdir(cwd)
+
+            if workdir and os.path.isdir(workdir):
+                os.chdir(workdir)
 
             pargs, _ = self.parse_known_args(project_args, self._env)
 
@@ -498,16 +502,3 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
 
         if self._logger:
             self._logger.log(level, msg, extra={"microname":".".join(name)})
-
-
-class MicroappProject(Project):
-    """Microapp default project"""
-
-    _name_ = "microapp"
-    _version_ = "0.3.14"
-    _description_ = "A command-line portal to Microapp apps."
-    _long_description_ = "A command-line portal to Microapp apps."
-    _author_ = "Youngsung Kim"
-    _author_email_ = "youngsung.kim.act2@gmail.com"
-    _url_ = "https://github.com/grnydawn/microapp"
-
