@@ -92,9 +92,9 @@ class ShellApp(App):
         from subprocess import Popen, PIPE
        
         cmds = args.command["_"] if args.useenv else split(args.command["_"])
-        cwd = args.workdir["_"] if args.workdir else None
+        workdir = args.workdir["_"] if args.workdir else None
 
-        proc = Popen(cmds, stdout=PIPE, stderr=PIPE, shell=args.useenv, cwd=cwd)
+        proc = Popen(cmds, stdout=PIPE, stderr=PIPE, shell=args.useenv, cwd=workdir)
 
         outs, errs = proc.communicate()
 
